==> qmmp-0.4.5.tar.bz2: qmmp-0.4.5/src/plugins/Input/modplug/translations/modplug_plugin_tr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="tr_TR">
<context>
    <name>DecoderModPlugFactory</name>
    <message>
        <location filename="../decodermodplugfactory.cpp" line="60"/>
        <source>ModPlug Plugin</source>
        <translation>ModPlug Eklentisi</translation>
    </message>
    <message>
        <location filename="../decodermodplugfactory.cpp" line="64"/>
        <source>ModPlug Files</source>
        <translation>ModPlug Dosyaları</translation>
    </message>
    <message>
        <location filename="../decodermodplugfactory.cpp" line="130"/>
        <source>About ModPlug Audio Plugin</source>
        <translation>ModPlug Ses Eklentisi Hakkında</translation>
    </message>
    <message>
        <location filename="../decodermodplugfactory.cpp" line="131"/>
        <source>Qmmp ModPlug Audio Plugin</source>
        <translation>Qmmp ModPlug Ses Eklentisi</translation>
    </message>
    <message>
        <location filename="../decodermodplugfactory.cpp" line="132"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Yazan: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
    <message>
        <location filename="../decodermodplugfactory.cpp" line="133"/>
        <source>Based on the Modplug Plugin for Xmms</source>
        <translation>Xmms için yazılan Modplug eklentisi temellidir</translation>
    </message>
    <message>
        <location filename="../decodermodplugfactory.cpp" line="134"/>
        <source>Modplug Plugin developers:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../decodermodplugfactory.cpp" line="135"/>
        <source>Olivier Lapicque &lt;olivierl@jps.net&gt;</source>
        <translation>Olivier Lapicque &lt;olivierl@jps.net&gt;</translation>
    </message>
    <message>
        <location filename="../decodermodplugfactory.cpp" line="136"/>
        <source>Kenton Varda &lt;temporal@gauge3d.org&gt;</source>
        <translation>Kenton Varda &lt;temporal@gauge3d.org&gt;</translation>
    </message>
    <message>
        <location filename="../decodermodplugfactory.cpp" line="137"/>
        <source>Konstanty Bialkowski &lt;konstanty@ieee.org&gt;</source>
        <translation>Konstanty Bialkowski &lt;konstanty@ieee.org&gt;</translation>
    </message>
</context>
<context>
    <name>ModPlugMetaDataModel</name>
    <message>
        <location filename="../modplugmetadatamodel.cpp" line="71"/>
        <source>File name</source>
        <translation type="unfinished">Dosya adı</translation>
    </message>
    <message>
        <location filename="../modplugmetadatamodel.cpp" line="142"/>
        <source>Type</source>
        <translation type="unfinished">Tip</translation>
    </message>
    <message>
        <location filename="../modplugmetadatamodel.cpp" line="147"/>
        <source>Length</source>
        <translation type="unfinished">Uzunluk</translation>
    </message>
    <message>
        <location filename="../modplugmetadatamodel.cpp" line="148"/>
        <source>Speed</source>
        <translation type="unfinished">Hız</translation>
    </message>
    <message>
        <location filename="../modplugmetadatamodel.cpp" line="149"/>
        <source>Tempo</source>
        <translation type="unfinished">Tempo</translation>
    </message>
    <message>
        <location filename="../modplugmetadatamodel.cpp" line="150"/>
        <location filename="../modplugmetadatamodel.cpp" line="171"/>
        <source>Samples</source>
        <translation type="unfinished">Örnekler</translation>
    </message>
    <message>
        <location filename="../modplugmetadatamodel.cpp" line="151"/>
        <location filename="../modplugmetadatamodel.cpp" line="180"/>
        <source>Instruments</source>
        <translation type="unfinished">Enstrümanlar</translation>
    </message>
    <message>
        <location filename="../modplugmetadatamodel.cpp" line="152"/>
        <source>Patterns</source>
        <translation type="unfinished">Desenler</translation>
    </message>
    <message>
        <location filename="../modplugmetadatamodel.cpp" line="153"/>
        <source>Channels</source>
        <translation type="unfinished">Kanallar</translation>
    </message>
    <message>
        <location filename="../modplugmetadatamodel.cpp" line="185"/>
        <source>Comment</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>ModPlug Plugin Settings</source>
        <translation>ModPlug Eklenti Ayarları</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="33"/>
        <source>Quality</source>
        <translation>Kalite</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="45"/>
        <source>Resolution</source>
        <translation>Çözünürlük</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="51"/>
        <source>16 bit</source>
        <translation>16 bit</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="58"/>
        <source>8 bit</source>
        <translation>8 bit</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="74"/>
        <source>Channels</source>
        <translation>Kanallar</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="80"/>
        <source>Stereo</source>
        <translation>Stereo</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="87"/>
        <source>Mono (downmix)</source>
        <translation>Mono (downmix)</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="103"/>
        <source>Resampling</source>
        <translation>Yeniden örnekleme</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="109"/>
        <source>Nearest (fastest)</source>
        <translation>En yakın (en hızlısı)</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="116"/>
        <source>Linear (fast)</source>
        <translation>Doğrusal (hızlı)</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="123"/>
        <source>Spline (good quality)</source>
        <translation>Çubuk (iyi kalitede)</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="130"/>
        <source>8-tap Fir (extremely high quality)</source>
        <translation>8-tap Fir (en yüksek kalitede)</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="146"/>
        <source>Sampling Rate</source>
        <translation>Örnekleme Oranı</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="152"/>
        <source>48000 Hz</source>
        <translation>48000 Hz</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="159"/>
        <source>44100 Hz</source>
        <translation>44100 Hz</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="166"/>
        <source>22050 Hz</source>
        <translation>22050 Hz</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="173"/>
        <source>11025 Hz</source>
        <translation>11025 Hz</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="184"/>
        <source>Effects</source>
        <translation>Efektler</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="190"/>
        <source>Reverb</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="202"/>
        <location filename="../settingsdialog.ui" line="467"/>
        <source>Depth (%)</source>
        <translation>Derinlik (%)</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="234"/>
        <location filename="../settingsdialog.ui" line="368"/>
        <location filename="../settingsdialog.ui" line="499"/>
        <location filename="../settingsdialog.ui" line="618"/>
        <source>0</source>
        <translation>0</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="260"/>
        <location filename="../settingsdialog.ui" line="519"/>
        <source>Delay (ms)</source>
        <translation>Gecikme (ms)</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="292"/>
        <source>40</source>
        <translation>40</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="324"/>
        <source>Bass Boost</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="336"/>
        <source>Amount (%)</source>
        <translation>Miktar (%)</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="394"/>
        <source>Range (Hz)</source>
        <translation>Aralık (Hz)</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="426"/>
        <source>10</source>
        <translation>10</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="458"/>
        <source>Surround</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="551"/>
        <source>5</source>
        <translation>5</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="577"/>
        <source>Preamp</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="586"/>
        <source>Volume</source>
        <translation>Ses</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="656"/>
        <source>Note: Setting the preamp
too high may cause clipping!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="671"/>
        <source>Misc</source>
        <translation>Çeşitli</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="677"/>
        <source>General</source>
        <translation>Genel</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="683"/>
        <source>Use filename as song title</source>
        <translation>Şarkı başlığı için dosya adını kullan</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="690"/>
        <source>Noise reduction</source>
        <translation>Gürültü azaltma</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="700"/>
        <source>Fast playlist info</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="710"/>
        <source>Play Amiga MOD</source>
        <translation>Amiga MOD Oynat</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="720"/>
        <source>Looping</source>
        <translation>Döngü</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="726"/>
        <source>Don&apos;t loop</source>
        <translation>Döngü kurma</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="733"/>
        <source>Loop</source>
        <translation>Döngü</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="750"/>
        <source>time(s)</source>
        <translation>süre(s)</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="770"/>
        <source>Loop forever</source>
        <translation>Sonsuz döngü</translation>
    </message>
</context>
</TS>

==> qmmp-0.8.4.tar.bz2: qmmp-0.8.4/src/plugins/Input/modplug/translations/modplug_plugin_tr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="tr">
<context>
    <name>DecoderModPlugFactory</name>
    <message>
        <location filename="../decodermodplugfactory.cpp" line="55"/>
        <source>ModPlug Plugin</source>
        <translation>ModPlug Eklentisi</translation>
    </message>
    <message>
        <location filename="../decodermodplugfactory.cpp" line="61"/>
        <source>ModPlug Files</source>
        <translation>ModPlug Dosyaları</translation>
    </message>
    <message>
        <location filename="../decodermodplugfactory.cpp" line="127"/>
        <source>About ModPlug Audio Plugin</source>
        <translation>ModPlug Ses Eklentisi Hakkında</translation>
    </message>
    <message>
        <location filename="../decodermodplugfactory.cpp" line="128"/>
        <source>Qmmp ModPlug Audio Plugin</source>
        <translation>Qmmp ModPlug Ses Eklentisi</translation>
    </message>
    <message>
        <location filename="../decodermodplugfactory.cpp" line="129"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../decodermodplugfactory.cpp" line="130"/>
        <source>Based on the Modplug Plugin for Xmms</source>
        <translation>Xmms için yazılan Modplug eklentisi temellidir</translation>
    </message>
    <message>
        <location filename="../decodermodplugfactory.cpp" line="131"/>
        <source>Modplug Plugin developers:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../decodermodplugfactory.cpp" line="132"/>
        <source>Olivier Lapicque &lt;olivierl@jps.net&gt;</source>
        <translation>Olivier Lapicque &lt;olivierl@jps.net&gt;</translation>
    </message>
    <message>
        <location filename="../decodermodplugfactory.cpp" line="133"/>
        <source>Kenton Varda &lt;temporal@gauge3d.org&gt;</source>
        <translation>Kenton Varda &lt;temporal@gauge3d.org&gt;</translation>
    </message>
    <message>
        <location filename="../decodermodplugfactory.cpp" line="134"/>
        <source>Konstanty Bialkowski &lt;konstanty@ieee.org&gt;</source>
        <translation>Konstanty Bialkowski &lt;konstanty@ieee.org&gt;</translation>
    </message>
</context>
<context>
    <name>ModPlugMetaDataModel</name>
    <message>
        <location filename="../modplugmetadatamodel.cpp" line="71"/>
        <source>File name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../modplugmetadatamodel.cpp" line="142"/>
        <source>Type</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../modplugmetadatamodel.cpp" line="147"/>
        <source>Length</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../modplugmetadatamodel.cpp" line="148"/>
        <source>Speed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../modplugmetadatamodel.cpp" line="149"/>
        <source>Tempo</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../modplugmetadatamodel.cpp" line="150"/>
        <location filename="../modplugmetadatamodel.cpp" line="171"/>
        <source>Samples</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../modplugmetadatamodel.cpp" line="151"/>
        <location filename="../modplugmetadatamodel.cpp" line="180"/>
        <source>Instruments</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../modplugmetadatamodel.cpp" line="152"/>
        <source>Patterns</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../modplugmetadatamodel.cpp" line="153"/>
        <source>Channels</source>
        <translation type="unfinished">Kanallar</translation>
    </message>
    <message>
        <location filename="../modplugmetadatamodel.cpp" line="185"/>
        <source>Comment</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>ModPlug Plugin Settings</source>
        <translation>ModPlug Eklenti Ayarları</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="33"/>
        <source>Quality</source>
        <translation>Kalite</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="45"/>
        <source>Resolution</source>
        <translation>Çözünürlük</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="51"/>
        <source>16 bit</source>
        <translation>16 bit</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="58"/>
        <source>8 bit</source>
        <translation>8 bit</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="74"/>
        <source>Channels</source>
        <translation>Kanallar</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="80"/>
        <source>Stereo</source>
        <translation>Stereo</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="87"/>
        <source>Mono (downmix)</source>
        <translation>Mono (downmix)</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="103"/>
        <source>Resampling</source>
        <translation>Yeniden örnekleme</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="109"/>
        <source>Nearest (fastest)</source>
        <translation>En yakın (en hızlısı)</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="116"/>
        <source>Linear (fast)</source>
        <translation>Doğrusal (hızlı)</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="123"/>
        <source>Spline (good quality)</source>
        <translation>Çubuk (iyi kalitede)</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="130"/>
        <source>8-tap Fir (extremely high quality)</source>
        <translation>8-tap Fir (en yüksek kalitede)</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="146"/>
        <source>Sampling Rate</source>
        <translation>Örnekleme Oranı</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="152"/>
        <source>48000 Hz</source>
        <translation>48000 Hz</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="159"/>
        <source>44100 Hz</source>
        <translation>44100 Hz</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="166"/>
        <source>22050 Hz</source>
        <translation>22050 Hz</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="173"/>
        <source>11025 Hz</source>
        <translation>11025 Hz</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="184"/>
        <source>Effects</source>
        <translation>Efektler</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="190"/>
        <source>Reverb</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="202"/>
        <location filename="../settingsdialog.ui" line="467"/>
        <source>Depth (%)</source>
        <translation>Derinlik (%)</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="234"/>
        <location filename="../settingsdialog.ui" line="368"/>
        <location filename="../settingsdialog.ui" line="499"/>
        <location filename="../settingsdialog.ui" line="618"/>
        <source>0</source>
        <translation>0</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="260"/>
        <location filename="../settingsdialog.ui" line="519"/>
        <source>Delay (ms)</source>
        <translation>Gecikme (ms)</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="292"/>
        <source>40</source>
        <translation>40</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="324"/>
        <source>Bass Boost</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="336"/>
        <source>Amount (%)</source>
        <translation>Miktar (%)</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="394"/>
        <source>Range (Hz)</source>
        <translation>Aralık (Hz)</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="426"/>
        <source>10</source>
        <translation>10</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="458"/>
        <source>Surround</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="551"/>
        <source>5</source>
        <translation>5</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="577"/>
        <source>Preamp</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="586"/>
        <source>Volume</source>
        <translation>Ses</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="656"/>
        <source>Note: Setting the preamp
too high may cause clipping!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="671"/>
        <source>Misc</source>
        <translation>Çeşitli</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="677"/>
        <source>General</source>
        <translation>Genel</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="683"/>
        <source>Use filename as song title</source>
        <translation>Şarkı başlığı için dosya adını kullan</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="690"/>
        <source>Noise reduction</source>
        <translation>Gürültü azaltma</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="700"/>
        <source>Fast playlist info</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="710"/>
        <source>Play Amiga MOD</source>
        <translation>Amiga MOD Oynat</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="720"/>
        <source>Looping</source>
        <translation>Döngü</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="726"/>
        <source>Don&apos;t loop</source>
        <translation>Döngü kurma</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="733"/>
        <source>Loop</source>
        <translation>Döngü</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="750"/>
        <source>time(s)</source>
        <translation>süre(s)</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="770"/>
        <source>Loop forever</source>
        <translation>Sonsuz döngü</translation>
    </message>
</context>
</TS>
